@@ -84,6 +84,8 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     _pre_merge_resolver: T.Optional["Resolver"] = PrivateAttr(None)
 
+    is_count: bool = False
+
     def __hash__(self):
         return hash(
             str(self._get_nested_query_variables()) + self.to_str() + self._model_name
@@ -617,6 +619,8 @@ class Resolver(BaseModel, T.Generic[NodeType]):
     def parse_nested_obj(
         self, raw_d: dict, error_for_extra_fields: bool = False
     ) -> NodeType:
+        if self.is_count and type(raw_d) is int:
+            return raw_d
         node: NodeType = self._node.parse_obj(raw_d)
         # pass on other fields as an "extra" dict
         # problem with this is aliases are currently also added to extra... do i want this?
